pub(crate) const HAS_MAXIMUM: bool = false;

pub(crate) type F64X2 = [f64; 2];

pub(crate) fn abs(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn add_rn(x: F64X2, y: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn add_ru(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn all(_: F64X2) -> bool {
    unimplemented!()
}

pub(crate) fn and(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn any(_: F64X2) -> bool {
    unimplemented!()
}

pub(crate) fn bitmask(_: F64X2) -> u32 {
    unimplemented!()
}

pub(crate) fn ceil(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn constant(_: f64, _: f64) -> F64X2 {
    unimplemented!()
}

pub(crate) fn div_ru(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn eq(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn extract(x: F64X2) -> [f64; 2] {
    unimplemented!()
}

pub(crate) fn extract0(_: F64X2) -> f64 {
    unimplemented!()
}

pub(crate) fn extract1(_: F64X2) -> f64 {
    unimplemented!()
}

pub(crate) fn floor(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn ge(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn gt(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn hadd_rn(x: F64X2, y: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn le(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn lt(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn max(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn maximum(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn min(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn minimum(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn mul_add_ru(_: F64X2, _: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn mul_ru(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn neg(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn neg0(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn or(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn round(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn round_ties_to_even(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn shuffle02(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn shuffle03(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn shuffle13(_: F64X2, _: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn splat(_: f64) -> F64X2 {
    unimplemented!()
}

pub(crate) fn sqrt1_rd(_: f64) -> f64 {
    unimplemented!()
}

pub(crate) fn sqrt1_ru(_: f64) -> f64 {
    unimplemented!()
}

pub(crate) fn sub_rn(x: F64X2, y: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn sub1_ru(_: f64, _: f64) -> f64 {
    unimplemented!()
}

pub(crate) fn swap(_: F64X2) -> F64X2 {
    unimplemented!()
}

pub(crate) fn trunc(_: F64X2) -> F64X2 {
    unimplemented!()
}
